==> vue-hooks-plus-1.6.2.tgz: package/es/useUrlState/index.js <==
import qs from "qs";
import { ref, watch } from "vue";
import { useLocalStorageState } from "../index";
import { isFunction } from "../utils";
function encodeParams(value) {
  return qs.stringify(value);
}
function decodeParams(valueStr, detectNumber) {
  return qs.parse(valueStr, {
    arrayLimit: 1e4,
    decoder(str, _, charset) {
      const strWithoutPlus = str.replace(/\+/g, " ");
      if (charset === "iso-8859-1") {
        return strWithoutPlus.replace(/%[0-9a-f]{2}/gi, unescape);
      }
      if (detectNumber && /^[+-]?\d+(\.\d+)?$/.test(str)) {
        return parseFloat(str);
      }
      const keywords = {
        true: true,
        false: false,
        null: null,
        undefined: void 0
      };
      if (str in keywords) {
        return keywords[str];
      }
      try {
        return decodeURIComponent(strWithoutPlus);
      } catch (e) {
        return strWithoutPlus;
      }
    }
  });
}
function useUrlState(initialState, options) {
  var _a;
  const routerPushFn = (options == null ? void 0 : options.routerPush) ? options.routerPush : (s) => location.hash = s;
  const { localStorageKey, detectNumber = true } = options != null ? options : {};
  const [path, paramsStr] = location.hash.slice(1).split("?");
  const defaultState = (_a = isFunction(initialState) ? initialState() : initialState) != null ? _a : {};
  const state = localStorageKey ? useLocalStorageState(localStorageKey, {
    defaultValue: defaultState
  })[0] : ref(defaultState);
  if (paramsStr) {
    try {
      const paramsValue = decodeParams(paramsStr, detectNumber);
      state.value = {
        ...defaultState,
        ...state.value,
        ...paramsValue
      };
    } catch {
      state.value = defaultState;
    }
  }
  if (initialState && Object.keys(initialState).length) {
    const newState = { ...initialState };
    for (const key in newState) {
      if (key in state.value) {
        newState[key] = state.value[key];
      }
    }
    state.value = newState;
  }
  watch(
    state,
    () => {
      const newParamsStr = encodeParams(state.value);
      routerPushFn(`${path}?${newParamsStr}`);
    },
    {
      deep: true,
      immediate: true
    }
  );
  return state;
}
export {
  useUrlState as default
};

==> vue-hooks-plus-1.7.4.tgz: package/es/useUrlState/index.js <==
import qs from "qs";
import { ref, watch } from "vue";
import { useLocalStorageState } from "../index";
import { isFunction } from "../utils";
function encodeParams(value) {
  return qs.stringify(value);
}
function decodeParams(valueStr, detectNumber) {
  return qs.parse(valueStr, {
    // fix: 数组长度限制问题
    arrayLimit: 1e4,
    decoder(str, _, charset) {
      const strWithoutPlus = str.replace(/\+/g, " ");
      if (charset === "iso-8859-1") {
        return strWithoutPlus.replace(/%[0-9a-f]{2}/gi, unescape);
      }
      if (detectNumber && /^[+-]?\d+(\.\d+)?$/.test(str)) {
        return parseFloat(str);
      }
      const keywords = {
        true: true,
        false: false,
        null: null,
        undefined: void 0
      };
      if (str in keywords) {
        return keywords[str];
      }
      try {
        return decodeURIComponent(strWithoutPlus);
      } catch (e) {
        return strWithoutPlus;
      }
    }
  });
}
function useUrlState(initialState, options) {
  const routerPushFn = (options == null ? void 0 : options.routerPush) ? options.routerPush : (s) => location.hash = s;
  const { localStorageKey, detectNumber = true } = options ?? {};
  const [path, paramsStr] = location.hash.slice(1).split("?");
  const defaultState = (isFunction(initialState) ? initialState() : initialState) ?? {};
  const state = localStorageKey ? useLocalStorageState(localStorageKey, {
    defaultValue: defaultState
  })[0] : ref(defaultState);
  if (paramsStr) {
    try {
      const paramsValue = decodeParams(paramsStr, detectNumber);
      state.value = {
        ...defaultState,
        ...state.value,
        ...paramsValue
      };
    } catch {
      state.value = defaultState;
    }
  }
  if (initialState && Object.keys(initialState).length) {
    const newState = { ...initialState };
    for (const key in newState) {
      if (key in state.value) {
        newState[key] = state.value[key];
      }
    }
    state.value = newState;
  }
  watch(
    state,
    () => {
      const newParamsStr = encodeParams(state.value);
      routerPushFn(`${path}?${newParamsStr}`);
    },
    {
      deep: true,
      immediate: true
    }
  );
  return state;
}
export {
  useUrlState as default
};
